<?php

require_once('library/displet-template-library.php');

/**
 * Functions below permitted for use in external applications (custom templates, custom theme functionality, etc.)
 * 
 * All function names, parameters, and return types/values are to remain unchanged
 */
	
/*****************************
/ Option related
*****************************/

/**
 * @param: none
 * @return: string
 */
function displetretsidx_get_api_key(){
	global $displetretsidx_option;
	return $displetretsidx_option['displet_app_key'];
}

/**
 * @param: none
 * @return: string
 */
function displetretsidx_get_property_details_page_id(){
	global $displetretsidx_option;
	return $displetretsidx_option['property_details_page_id'];
}

/**
 * @param: none
 * @return: string
 */
function displetretsidx_get_search_results_page_id(){
	global $displetretsidx_option;
	return $displetretsidx_option['search_results_page_id'];
}

/**
 * @param: $setting: string (min_price, max_price, price_increment, beds_min, beds_max, baths_min, baths_max, min_square_feet, max_square_feet, square_feet_increment, min_acres, max_acres, or acres_increment)
 * @return: success: integer
 * @return: failure: false
 */
function displetretsidx_get_search_value($setting){
	global $displetretsidx_option;
	if (isset($displetretsidx_option['search_values_' . $setting])) {
		return intval($displetretsidx_option['search_values_' . $setting]);
	}
	return false;
}

/**
 * @param: $field: string (area_mls_defined, city, property_type or school_district or status)
 * @return: success: array
 * @return: failure: false
 */
function displetretsidx_get_field_options($field){
	$field_option = DispletRetsIdxSettings::get_option('fields');
	if (isset($field_option[$field])) {
		return $field_option[$field];
	}
	return false;
}
	
/*****************************
/ Widget related
*****************************/

/**
 * @param: $column: integer
 * @return: boolean
 */
function displetretsidx_has_search_form($column = 1){
	$column = is_numeric($column) ? $column : 1;
	return DispletRetsIdxSearchResults::is_search_form_widget_area_used($column);
}

/**
 * @param: $column: integer
 * @return: print: dynamic_sidebar
 */
function displetretsidx_get_search_form($column = 1){
	$column = is_numeric($column) ? $column : 1;
	DispletRetsIdxUtilities::get_widget_area('displetretsidx-search-form-' . $column, 'Displet Search Form');
}

/**
 * @param: $column: integer
 * @return: boolean
 */
function displetretsidx_has_advanced_search_form($column = 1){
	$column = is_numeric($column) ? $column : 1;
	return DispletRetsIdxSearchResults::is_advanced_search_form_widget_area_used($column);
}

/**
 * @param: $column: integer
 * @return: print: dynamic_sidebar
 */
function displetretsidx_get_advanced_search_form($column = 1){
	$column = is_numeric($column) ? $column : 1;
	DispletRetsIdxUtilities::get_widget_area('displetretsidx-search-form-advanced-' . $column, 'Displet Search Form - Adv. Section');
}

/**
 * @param: $id: integer, $column: integer
 * @return: boolean
 */
function displetretsidx_has_quick_search_form($id, $column = 1){
	$id = is_numeric($id) ? $id : 1;
	$column = is_numeric($column) ? $column : 1;
	return DispletRetsIdxSearchFormWidgets::is_quick_search_form_column_used($id, $column);
}

/**
 * @param: $id: integer, $column: integer
 * @return: print: dynamic_sidebar
 */
function displetretsidx_get_quick_search_form($id, $column = 1){
	$id = is_numeric($id) ? $id : 1;
	$column = is_numeric($column) ? $column : 1;
	DispletRetsIdxUtilities::get_widget_area('displetretsidx-quick-search-' . $id . '-form-' . $column, 'Displet Quick Search ' . $id . ' Form');
}

/**
 * @param: none
 * @return: print: dynamic_sidebar
 */
function displetretsidx_get_mobile_search_form(){
	DispletRetsIdxUtilities::get_widget_area('displetretsidx-search-form-mobile', 'Displet Mobile Search Form');
}

/**
 * @param: none
 * @return: print: dynamic_sidebar
 */
function displetretsidx_get_mobile_quick_search_form(){
	DispletRetsIdxUtilities::get_widget_area('displetretsidx-quick-search-form-mobile', 'Displet Mobile Quick Search Form');
}

/**
 * @param: none
 * @return: print: dynamic_sidebar
 */
function displetretsidx_get_mobile_contact_page_top(){
	DispletRetsIdxUtilities::get_widget_area('displetretsidx-mobile-contact-top', 'Displet Mobile Contact Page Top', false);
}

/**
 * @param: none
 * @return: print: dynamic_sidebar
 */
function displetretsidx_get_mobile_contact_page_bottom(){
	DispletRetsIdxUtilities::get_widget_area('displetretsidx-mobile-contact-bottom', 'Displet Mobile Contact Page Bottom', false);
}
	
/*****************************
/ Menu related
*****************************/

/**
 * @param: none
 * @return: wp_nav_menu
 */
function displetretsidx_get_mobile_menu(){
	return wp_nav_menu(array(
		'theme_location' => 'displetretsidx_mobile_menu',
		'echo' => false,
		'fallback_cb' => false
	));
}

/*****************************
/ Listings related
*****************************/

/**
 * @param: $criteria: array('field' => 'value'); $num_listings: integer, 1-50
 * @return: success - array: $results['listings'] = object(stdClass), $results['meta'] = object(stdClass), $results['query_url'] = string
 * @return: failure - boolean: false
 */
function displetretsidx_get_listings($criteria, $num_listings = false){
	$model = DispletRetsIdxModel::get_model();
	if (!empty($criteria) && is_array($criteria)) {
		$shortcode_translations = DispletRetsIdxResidentials::get_shortcode_translations(false);
		$shortcode_translations_reverse = array_flip($shortcode_translations);
		foreach ($criteria as $key => $value) {
			if (!empty($shortcode_translations_reverse[$key])) {
				$model[$shortcode_translations_reverse[$key]] = $value;
			}
		}
	}
	if (!empty($num_listings) && is_numeric($num_listings)) {
		$the_count = intval($num_listings);
		if ($the_count > 0 && $the_count < 50) {
			$model['listings_per_page'] = $the_count;
		}
	}
	if (!empty($criteria['return_fields'])) {
		$model['return_fields'] = $criteria['return_fields'];
	}
	if (!empty($criteria['page']) && is_numeric($criteria['page'])) {
		$the_page = intval($criteria['page']);
		if ($the_page > 0) {
			$model['page'] = $the_page;
		}
	}
	$model = DispletRetsIdxResidentialsApi::get_listings($model, false);
	if (!empty($model['listings'])) {
		$results = array(
			'listings' => $model['listings'],
			'meta' => $model['meta'],
			'query_url' => $model['query_url']
		);
		return $results;
	}
	return false;
}

/**
 * @param: $criteria: array('field' => 'value')
 * @return: success - integer
 * @return: failure - boolean: false
 */
function displetretsidx_get_count($criteria = false){
	$model = DispletRetsIdxModel::get_model();
	if (!empty($criteria) && is_array($criteria)) {
		$shortcode_translations = DispletRetsIdxResidentials::get_shortcode_translations(false);
		$shortcode_translations_reverse = array_flip($shortcode_translations);
		foreach ($criteria as $key => $value) {
			if (!empty($shortcode_translations_reverse[$key])) {
				$model[$shortcode_translations_reverse[$key]] = $value;
			}
		}
	}
	$count = DispletRetsIdxResidentialsApi::get_count($model);
	if (!empty($count)) {
		return $count;
	}
	return false;
}

?>