<?php

/*
 * Plugin name: Displet RETS/IDX
 * Plugin URI: http://displet.com/wordpress-plugins/displetreader-wordpress-plugin
 * Description: RETS/IDX Plugin that inserts real estate listings, statistics, maps, and quick searches into Wordpress pages & widget ready sidebars. Free version available.
 * Version: 2.0.32
 * Author: Displet
 * Author URI: http://displet.com/
 * License: GPL2
 */

/*  Copyright 2011 Displet (email : dev@displet.com)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2, as 
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

abstract class DispletRetsIdxPlugin{
	protected static $plugin_version = '2.0.32';
	protected static $api_url = 'http://api.displet.com';
	protected static $settings_option = 'displet_rets_idx_options';
	protected static $version_option = 'displet_rets_idx_plugin';
	protected static $notify_option = 'displet_rets_idx_version';
	protected static $field_option = 'displet_rets_idx_field_options';
	protected static $action_option = 'displet_rets_idx_action_options';

	public function include_version(){
		echo '<!-- Displet RETS/IDX v. ' . self::$plugin_version . ' -->';
	}

	public function maybe_notify(){
		global $displetretsidx_option;
		$last_version = DispletRetsIdxSettings::get_option('notify');
		if (version_compare(self::$plugin_version, $last_version, '>')) {
			if (version_compare('2.0.12', $last_version, '>') && empty($displetretsidx_option['displet_app_token'])) {
				$model = array(
					'version' => '2.0.12',
					'message' => '<h3>Attention: Existing Displet Users</h3><p>Please take notice that we have recently upgraded our security procedures and have <b>added an API password</b> to your settings page. If you have already authenticated, <b>you do not need to enter a password</b>, but may wish to request the password for future use by <a href="http://displet.zendesk.com" target="_blank">submitting a ticket</a>.</p>'
				);
				echo DispletRetsIdxLoad::get_admin_template('displet-notification-jquery.php', $model);
			}
			else if (version_compare('2.0.13', $last_version, '>')) {
				$model = array(
					'version' => '2.0.13',
					'message' => '<h3>New Displet Feature</h3><p>You can now view your users favorites & saved searches directly from your lead management screen. Click the details link next to each lead.</p>'
				);
				echo DispletRetsIdxLoad::get_admin_template('displet-notification-jquery.php', $model);
			}
			else if (version_compare('2.0.25', $last_version, '>')) {
				$model = array(
					'version' => '2.0.25',
					'message' => '<h3>New Displet Feature</h3><p>We\'ve given the login/regisration prompt a facelift and new options! Take a look on your RE Search Settings page to find the newly added <b>"soft prompt"</b> and <b>"back prompt"</b> options, which offer more flexibility on how you\'d like to encourage registration. Soft prompts can be closed, and back prompts return you to the previous page.</p>'
				);
				echo DispletRetsIdxLoad::get_admin_template('displet-notification-jquery.php', $model);
			}
			else {
				DispletRetsIdxSettings::update_option('notify', self::$plugin_version);
			}
		}
	}

	public function maybe_deactivate(){
		$active_plugins = get_option('active_plugins');
		if (!empty($active_plugins) && is_array($active_plugins)) {
			$plugins = array();
			$alert = false;
			foreach ($active_plugins as $plugin) {
				if ($plugin == 'displetsearch-wordpress-plugin/DispletReader.php') {
					$alert = true;
				}
				if ($plugin != 'displetreader-wordpress-plugin/displetreader-wordpress-plugin.php') {
					$plugins[] = $plugin;
				}
			}
			if ($alert) {
				update_option('displetretsidx_deactivated', true);
				wp_schedule_single_event(time(), 'displetretsidx_update_active_plugins', array($plugins));
			}
		}
	}

	public function maybe_notify_of_deactivation(){
		$deactivated = get_option('displetretsidx_deactivated');
		if (!empty($deactivated)) {
			echo '<div class="error"><h3>Warning! Displet RETS/IDX Deactivated</h3><p>Displet RETS/IDX was deactivated because it appears DispletReader Legacy is currently active. If you wish to use Displet RETS/IDX, please first deactivate DispletReader Legacy.</p></div>';
			update_option('displetretsidx_deactivated', false);
		}
	}

	public function update_active_plugins($plugins){
		update_option('active_plugins', $plugins);
	}
}

add_action('wp_head', array('DispletRetsIdxPlugin', 'include_version'), 1000000);
add_action('admin_head', array('DispletRetsIdxPlugin', 'maybe_notify'));
add_action('displetretsidx_update_active_plugins', array('DispletRetsIdxPlugin', 'update_active_plugins'));
add_action('admin_notices', array('DispletRetsIdxPlugin', 'maybe_notify_of_deactivation'));
register_activation_hook(__FILE__, array('DispletRetsIdxPlugin', 'maybe_deactivate'));
register_activation_hook(__FILE__, array('DispletRetsIdxSettings', 'register_default_settings'));
register_activation_hook(__FILE__, array('DispletRetsIdxSearchFormWidgets', 'register_default_widgets'));
register_activation_hook(__FILE__, array('DispletRetsIdxSearchFormWidgets', 'register_default_widget_areas_content'));
register_activation_hook(__FILE__, array('DispletRetsIdxUrlStructure', 'reset_flush_rewrite_rules'));
register_activation_hook(__FILE__, array('DispletRetsIdxEmails', 'adjust_activity_report_schedule'));
register_deactivation_hook(__FILE__, array('DispletRetsIdxEmails', 'unschedule_activity_report'));

require_once('displet-api.php');
require_once('displet-emails.php');
require_once('displet-email-templates.php');
require_once('displet-google-login.php');
require_once('displet-library.php');
require_once('displet-load.php');
require_once('displet-mobile.php');
require_once('includes/displet-mobile-detect.php');
require_once('displet-model.php');
require_once('displet-quick-start.php');
require_once('displet-property-details.php');
require_once('displet-residentials.php');
require_once('displet-search-results.php');
require_once('displet-search-form-widgets.php');
require_once('displet-shortcodes.php');
require_once('displet-tinymce.php');
require_once('displet-settings.php');
require_once('displet-settings-updates.php');
require_once('displet-updates.php');
require_once('displet-url-structure.php');
require_once('displet-users.php');
require_once('displet-users-updates.php');
require_once('displet-utilities.php');
require_once('displet-widgets.php');

?>